@@ -21,6 +21,7 @@
 #include <config.h>
 
 #include <string.h>
+#include <math.h>
 
 #include <gtk/gtk.h>
 
@@ -363,3 +364,17 @@ ev_document_misc_invert_pixbuf (GdkPixbuf *pixbuf)
 		}
 	}
 }
+
+gdouble
+ev_document_misc_get_screen_dpi (GdkScreen *screen)
+{
+	gdouble dp, di;
+
+	/*diagonal in pixels*/
+	dp = hypot (gdk_screen_get_width (screen), gdk_screen_get_height (screen));
+
+	/*diagonal in inches*/
+	di = hypot (gdk_screen_get_width_mm(screen), gdk_screen_get_height_mm (screen)) / 25.4;
+
+	return (dp / di);
+}
