@@ -143,8 +143,8 @@ egg_find_bar_class_init (EggFindBarClass *klass)
   g_object_class_install_property (object_class,
 				   PROP_SEARCH_STRING,
 				   g_param_spec_string ("search_string",
-							_("Search string"),
-							_("The name of the string to be found"),
+							"Search string",
+							"The name of the string to be found",
 							NULL,
 							G_PARAM_READWRITE));
 
@@ -157,23 +157,23 @@ egg_find_bar_class_init (EggFindBarClass *klass)
   g_object_class_install_property (object_class,
 				   PROP_CASE_SENSITIVE,
 				   g_param_spec_boolean ("case_sensitive",
-                                                         _("Case sensitive"),
-                                                         _("TRUE for a case sensitive search"),
+                                                         "Case sensitive",
+                                                         "TRUE for a case sensitive search",
                                                          FALSE,
                                                          G_PARAM_READWRITE));
 
   /* Style properties */
   gtk_widget_class_install_style_property (widget_class,
                                            g_param_spec_boxed ("all_matches_color",
-                                                               _("Highlight color"),
-                                                               _("Color of highlight for all matches"),
+                                                               "Highlight color",
+                                                               "Color of highlight for all matches",
                                                                GDK_TYPE_COLOR,
                                                                G_PARAM_READABLE));
 
   gtk_widget_class_install_style_property (widget_class,
                                            g_param_spec_boxed ("current_match_color",
-                                                               _("Current color"),
-                                                               _("Color of highlight for the current match"),
+                                                               "Current color",
+                                                               "Color of highlight for the current match",
                                                                GDK_TYPE_COLOR,
                                                                G_PARAM_READABLE));
 
@@ -326,29 +326,19 @@ egg_find_bar_init (EggFindBar *find_bar)
 
   /* Prev */
   arrow = gtk_arrow_new (GTK_ARROW_LEFT, GTK_SHADOW_NONE);
-  priv->previous_button = gtk_tool_button_new (arrow, Q_("Find Previous"));
+  priv->previous_button = gtk_tool_button_new (arrow, Q_("Find Pre_vious"));
+  gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (priv->previous_button), TRUE);
   gtk_tool_item_set_is_important (priv->previous_button, TRUE);
-#if GTK_CHECK_VERSION (2, 11, 5)
   gtk_widget_set_tooltip_text (GTK_WIDGET (priv->previous_button),
 			       _("Find previous occurrence of the search string"));
-#else
-  gtk_tool_item_set_tooltip (priv->previous_button, GTK_TOOLBAR (find_bar)->tooltips,
-		             _("Find previous occurrence of the search string"),
-		             NULL);
-#endif
 
   /* Next */
   arrow = gtk_arrow_new (GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
-  priv->next_button = gtk_tool_button_new (arrow, Q_("Find Next"));
+  priv->next_button = gtk_tool_button_new (arrow, Q_("Find Ne_xt"));
+  gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (priv->next_button), TRUE);
   gtk_tool_item_set_is_important (priv->next_button, TRUE);
-#if GTK_CHECK_VERSION (2, 11, 5)
   gtk_widget_set_tooltip_text (GTK_WIDGET (priv->next_button),
 			       _("Find next occurrence of the search string"));
-#else
-  gtk_tool_item_set_tooltip (priv->next_button, GTK_TOOLBAR (find_bar)->tooltips,
-		             _("Find next occurrence of the search string"),
-		             NULL);
-#endif
 
   /* Separator*/
   priv->status_separator = gtk_separator_tool_item_new();
@@ -357,14 +347,9 @@ egg_find_bar_init (EggFindBar *find_bar)
   priv->case_button = gtk_toggle_tool_button_new ();
   g_object_set (G_OBJECT (priv->case_button), "label", _("C_ase Sensitive"), NULL);
   gtk_tool_item_set_is_important (priv->case_button, TRUE);
-#if GTK_CHECK_VERSION (2, 11, 5)
   gtk_widget_set_tooltip_text (GTK_WIDGET (priv->case_button),
 			       _("Toggle case sensitive search"));
-#else  
-  gtk_tool_item_set_tooltip (priv->case_button, GTK_TOOLBAR (find_bar)->tooltips,
-		             _("Toggle case sensitive search"),
-		             NULL);
-#endif
+
   /* Status */
   priv->status_item = gtk_tool_item_new();
   gtk_tool_item_set_expand (priv->status_item, TRUE);
